/*
 * Copyright (c) 2010 David McIntosh <dmcintosh@df12.net>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#import <AppKit/AppKit.h>
#import <Renaissance/Renaissance.h>
#import "util.h"
#import "GanttView.h"
#import "GanttTask.h"
#import "GanttModel.h"


@interface GanttController : GSMarkupDocument
{
    int nextTag;
    GanttModel  *tasks;
    NSMutableDictionary *toolbarItems;
    GanttView   *_ganttView;
    NSOutlineView *_tableView;
}

-(NSInteger)rootTasks;
-(NSEnumerator *)rootTaskEnumerator;
-(GanttTask *)taskAtIndex:(NSInteger)index;
-(NSDate *)earliestStartDate;
-(NSDate *)latestEndDate;

-(void)setGanttView:(GanttView *)aGanttView;
-(GanttView *)ganttView;
-(void)setTableView:(id)aTableView;
-(id)tableView;
-(GanttModel *)tasks;

- (GanttTask *)newTask;

-(void)userUpdatedCompletion:(id)sender;
-(void)userUpdatedStartDate:(id)sender;
-(void)userUpdatedEndDate:(id)sender;

// toolbar delegate methods
- (NSToolbarItem *)toolbar:(NSToolbar *)toolbar 
    itemForItemIdentifier:(NSString *)itemIdentifier 
    willBeInsertedIntoToolbar:(BOOL)flag;
- (NSArray *)toolbarAllowedItemIdentifiers:(NSToolbar*)toolbar;
- (NSArray *)toolbarDefaultItemIdentifiers:(NSToolbar*)toolbar;
- (NSArray *)toolbarSelectableItemIdentifiers:(NSToolbar *)toolbar;

// toolbar validation
- (BOOL)validateToolbarItem:(NSToolbarItem *)theItem;

- (void)zoomIn:(id)sender;
- (void)zoomOut:(id)sender;
- (void)addNewTask:(id)sender;
- (void)addChildToSelectedTask:(id)sender;
- (void)removeTask:(id)sender;

@end
